pub struct UserSession {Show 13 fields
session: WeakRef<Session>,
device_id: OnceCell<OwnedDeviceId>,
data: RefCell<Option<UserSessionData>>,
is_current: Cell<bool>,
device_id_string: PhantomData<String>,
display_name: PhantomData<String>,
display_name_or_device_id: PhantomData<String>,
last_seen_ip: PhantomData<Option<String>>,
last_seen_ts: PhantomData<u64>,
last_seen_datetime: PhantomData<Option<DateTime>>,
last_seen_datetime_string: PhantomData<Option<String>>,
verified: PhantomData<bool>,
system_settings_handler: RefCell<Option<SignalHandlerId>>,
}Fields
session: WeakRef<Session>The current session.
device_id: OnceCell<OwnedDeviceId>The ID of the user session.
data: RefCell<Option<UserSessionData>>The user session data.
is_current: Cell<bool>Whether this is the current user session.
device_id_string: PhantomData<String>The ID of the user session, as a string.
display_name: PhantomData<String>The display name of the device.
display_name_or_device_id: PhantomData<String>The display name of the device, or the device id as a fallback.
last_seen_ip: PhantomData<Option<String>>The last IP address used by the user session.
last_seen_ts: PhantomData<u64>The last time the user session was used, as the number of milliseconds since Unix EPOCH.
last_seen_datetime: PhantomData<Option<DateTime>>The last time the user session was used, as a GDateTime.
last_seen_datetime_string: PhantomData<Option<String>>The last time the user session was used, as a formatted string.
verified: PhantomData<bool>Whether this user session is verified.
system_settings_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl UserSession
impl UserSession
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl UserSession
impl UserSession
Sourcepub(super) fn set_device_id(&self, device_id: OwnedDeviceId)
pub(super) fn set_device_id(&self, device_id: OwnedDeviceId)
She the ID of this user session.
Sourcepub(super) fn set_data(&self, data: UserSessionData)
pub(super) fn set_data(&self, data: UserSessionData)
Set the user session data.
Sourcefn device_id_string(&self) -> String
fn device_id_string(&self) -> String
The ID of this user session, as a string.
Sourcefn display_name(&self) -> String
fn display_name(&self) -> String
The display name of the device.
Sourcepub(super) fn set_display_name(&self, name: String)
pub(super) fn set_display_name(&self, name: String)
Set the display name of the device.
Sourcefn display_name_or_device_id(&self) -> String
fn display_name_or_device_id(&self) -> String
The display name of the device, or the device id as a fallback.
Sourcefn last_seen_ip(&self) -> Option<String>
fn last_seen_ip(&self) -> Option<String>
The last IP address used by the user session.
Sourcefn last_seen_ts(&self) -> u64
fn last_seen_ts(&self) -> u64
The last time the user session was used, as the number of milliseconds since Unix EPOCH.
Defaults to 0 if the timestamp is unknown.
Sourcefn last_seen_datetime(&self) -> Option<DateTime>
fn last_seen_datetime(&self) -> Option<DateTime>
The last time the user session was used, as a GDateTime.
Sourcepub(super) fn last_seen_datetime_string(&self) -> Option<String>
pub(super) fn last_seen_datetime_string(&self) -> Option<String>
The last time the user session was used, as a localized formatted string.